.. dispatches-data-packages documentation master file, created by
   sphinx-quickstart on Mon Mar 13 23:30:35 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to dispatches-data-packages's documentation!
====================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

API Reference
=============

.. automodule:: dispatches_data.api
   :members:
